@@ -1,4 +1,4 @@
-""""This module provides a wrapper method for extracting embeddings from text using different models."""
+"""This module provides a wrapper method for extracting embeddings from text using different models."""
 
 from typing import List, Optional
 
@@ -6,14 +6,11 @@ import torch
 
 from senselab.text.tasks.embeddings_extraction.huggingface import HFFactory
 from senselab.text.tasks.embeddings_extraction.sentence_transformers import SentenceTransformerFactory
-from senselab.utils.data_structures.device import DeviceType
-from senselab.utils.data_structures.model import HFModel, SenselabModel, SentenceTransformersModel
+from senselab.utils.data_structures import DeviceType, HFModel, SenselabModel, SentenceTransformersModel
 
 
 def extract_embeddings_from_text(
-    pieces_of_text: List[str],
-    model: SenselabModel,
-    device: Optional[DeviceType] = None
+    pieces_of_text: List[str], model: SenselabModel, device: Optional[DeviceType] = None
 ) -> List[torch.Tensor]:
     """Extracts embeddings from a list of strings using the specified model.
 
